<?php

declare(strict_types=1);

namespace Drupal\entity_deep_token\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Entity\ContentEntityInterface;

/**
 * Configure Entity deep token settings for this site.
 */
final class SettingsForm extends ConfigFormBase {


  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return 'entity_deep_token_settings';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['entity_deep_token.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {


    $entity_type_manager = \Drupal::service('entity_type.manager');
    $definitions = $entity_type_manager->getDefinitions();
    $content_entities = [];
    foreach ($definitions as $entity_type_id => $definition) {
      if (is_subclass_of($definition->getClass(), ContentEntityInterface::class)) {
        $content_entities[$entity_type_id] = $entity_type_id;
      }
    }

    $config = $this->config('entity_deep_token.settings');
    $default = $config->get('content_list') ?? [];
    $form['content_list'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Content Type(s)'),
      '#options' => $content_entities,
      '#required' => TRUE,
      '#default_value' => $default,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state): void {

    parent::validateForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config('entity_deep_token.settings')
      ->set('content_list', $form_state->getValue('content_list'))
      ->save();
    parent::submitForm($form, $form_state);
  }

}
